# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`rsyslog`](#rsyslog): Set up Rsyslog 8
* [`rsyslog::server`](#rsyslog--server): Sets up the RSyslog server

#### Private Classes

* `rsyslog::config`
* `rsyslog::config::logrotate`: Default log rotation for RSyslog
* `rsyslog::install`: Installs the packages necessary for use of RSyslog
* `rsyslog::server::firewall`: Sets up the firewall rules for RSyslog with management by ``simp/iptables``
* `rsyslog::server::selinux`: Sets up SELinux for RSyslog
* `rsyslog::server::tcpwrappers`: Sets up TCPWrappers for RSyslog both plain TCP and TCP over TLS as necessary
* `rsyslog::service`: Manage the RSyslog service

### Defined types

* [`rsyslog::rule`](#rsyslog--rule): Adds a rule
* [`rsyslog::rule::console`](#rsyslog--rule--console): Add a rule for writing logs to the console
* [`rsyslog::rule::data_source`](#rsyslog--rule--data_source): Add a rule for collecting logs from files on the system
* [`rsyslog::rule::drop`](#rsyslog--rule--drop): Add a rule to drop content
* [`rsyslog::rule::local`](#rsyslog--rule--local): Add a rule targeting writing local system logs
* [`rsyslog::rule::other`](#rsyslog--rule--other): Adds an arbitrary rule
* [`rsyslog::rule::remote`](#rsyslog--rule--remote): Adds a rule to send messages to one or more remote system
* [`rsyslog::template::list`](#rsyslog--template--list): Add a template list to the rsyslog configuration file
* [`rsyslog::template::plugin`](#rsyslog--template--plugin): Add template plugins to the rsyslog configuration file.
* [`rsyslog::template::string`](#rsyslog--template--string): Add template strings to the rsyslog configuration
* [`rsyslog::template::subtree`](#rsyslog--template--subtree): Add template subtrees to the rsyslog configuration

### Data types

* [`Rsyslog::Boolean`](#Rsyslog--Boolean): Representation of boolean values that are translated to 'on' and 'off' in Rsyslog configuration
* [`Rsyslog::Options`](#Rsyslog--Options): Hash of options to be used for Rsyslog global, legacy global or module configuration
* [`Rsyslog::QueueType`](#Rsyslog--QueueType): Rsyslog Queue Types

## Classes

### <a name="rsyslog"></a>`rsyslog`

The configuration is particularly slanted toward the issues present in the
versions of rsyslog included with Enterprise Linux systems. It should still
work on other systems but they may have different/other bugs that have not
been addressed.

See ``rsyslog::config`` for additional, detailed configuration.

#### Examples

##### Create rules via hieradata:

```puppet
rsyslog::rules:
  'some_path/99_collect_kernel_errors.conf':
    content: "if prifilt('kern.err') then /var/log/kernel_errors.log"
  'some_path/98_discard_info.conf':
    content: "if prifilt('*.info') then stop"
```

#### Parameters

The following parameters are available in the `rsyslog` class:

* [`service_name`](#-rsyslog--service_name)
* [`package_name`](#-rsyslog--package_name)
* [`tls_package_name`](#-rsyslog--tls_package_name)
* [`trusted_nets`](#-rsyslog--trusted_nets)
* [`enable_tls_logging`](#-rsyslog--enable_tls_logging)
* [`log_servers`](#-rsyslog--log_servers)
* [`failover_log_servers`](#-rsyslog--failover_log_servers)
* [`queue_spool_directory`](#-rsyslog--queue_spool_directory)
* [`rule_dir`](#-rsyslog--rule_dir)
* [`tcp_server`](#-rsyslog--tcp_server)
* [`tcp_listen_port`](#-rsyslog--tcp_listen_port)
* [`tls_tcp_server`](#-rsyslog--tls_tcp_server)
* [`tls_tcp_listen_port`](#-rsyslog--tls_tcp_listen_port)
* [`udp_server`](#-rsyslog--udp_server)
* [`udp_listen_address`](#-rsyslog--udp_listen_address)
* [`udp_listen_port`](#-rsyslog--udp_listen_port)
* [`read_journald`](#-rsyslog--read_journald)
* [`logrotate`](#-rsyslog--logrotate)
* [`pki`](#-rsyslog--pki)
* [`app_pki_external_source`](#-rsyslog--app_pki_external_source)
* [`app_pki_dir`](#-rsyslog--app_pki_dir)
* [`rules`](#-rsyslog--rules)

##### <a name="-rsyslog--service_name"></a>`service_name`

Data type: `String`

The name of the Rsyslog service; typically ``rsyslog``

Default value: `'rsyslog'`

##### <a name="-rsyslog--package_name"></a>`package_name`

Data type: `String`

The name of the Rsyslog package to install; typically ``rsyslog``

Default value: `'rsyslog'`

##### <a name="-rsyslog--tls_package_name"></a>`tls_package_name`

Data type: `String`

The name of the Rsyslog package to install TLS utilities; typically ``rsyslog-gnutls``

Default value: `"${package_name}-gnutls"`

##### <a name="-rsyslog--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

A list of subnets (in CIDR notation) permitted access

* This will be used in conjunction with ``simp\iptables`` (if enabled)
  to allow connections from within the given subnets.

Default value: `simplib::lookup('simp_options::trusted_nets', {'default_value'                  => ['127.0.0.1/32'] })`

##### <a name="-rsyslog--enable_tls_logging"></a>`enable_tls_logging`

Data type: `Boolean`

Enable the TLS libraries where applicable

* If enabled, clients will encrypt all log data being sent to the given log
  servers.  Also, all log servers specified to use TLS (see
  ``rsyslog::server::tls_tcp_server``) will load the ``imtcp`` module and
  configure it for TLS.

Default value: `false`

##### <a name="-rsyslog--log_servers"></a>`log_servers`

Data type: `Simplib::Netlist`

A list of primary Rsyslog servers

* All nodes in this list will get a copy of **all** logs if remote logging
  is enabled.

Default value: `simplib::lookup('simp_options::syslog::log_servers', { 'default_value'          => [] })`

##### <a name="-rsyslog--failover_log_servers"></a>`failover_log_servers`

Data type: `Simplib::Netlist`

A list of the failover Rsyslog servers

* This **order-dependent** list will serve as all of the possible failover
  log servers for clients to send to if the servers in ``log_servers`` are
  unavailable.

Default value: `simplib::lookup('simp_options::syslog::failover_log_servers', { 'default_value' => [] })`

##### <a name="-rsyslog--queue_spool_directory"></a>`queue_spool_directory`

Data type: `Stdlib::Absolutepath`

The path to the directory where Rsyslog should store disk message queues

Default value: `'/var/spool/rsyslog'`

##### <a name="-rsyslog--rule_dir"></a>`rule_dir`

Data type: `Stdlib::Absolutepath`

The path at which all managed rules will begin

Default value: `'/etc/rsyslog.simp.d'`

##### <a name="-rsyslog--tcp_server"></a>`tcp_server`

Data type: `Boolean`

Make this host listen for ``TCP`` connections

* Ideally, all connections would be ``TLS`` enabled via ``$tls_tcp_server``
  instead.
* Only enable this if necessary.

Default value: `false`

##### <a name="-rsyslog--tcp_listen_port"></a>`tcp_listen_port`

Data type: `Simplib::Port`

The port upon which to listen for regular ``TCP`` connections

Default value: `514`

##### <a name="-rsyslog--tls_tcp_server"></a>`tls_tcp_server`

Data type: `Boolean`

Make this host listen for ``TLS`` enabled ``TCP`` connections

Default value: `false`

##### <a name="-rsyslog--tls_tcp_listen_port"></a>`tls_tcp_listen_port`

Data type: `Simplib::Port`

The port upon which to listen for ``TLS`` enabled ``TCP`` connections

Default value: `6514`

##### <a name="-rsyslog--udp_server"></a>`udp_server`

Data type: `Boolean`

Make this host listen for ``UDP`` connections

* This really should not be enabled unless you have devices that cannot
  speak ``TLS``

Default value: `false`

##### <a name="-rsyslog--udp_listen_address"></a>`udp_listen_address`

Data type: `String`

The address upon which to listen for ``UDP`` connections

* The default of ``127.0.0.1`` is set primariliy for supporting Java
  applications that cannot work with a modern method of logging.

Default value: `'127.0.0.1'`

##### <a name="-rsyslog--udp_listen_port"></a>`udp_listen_port`

Data type: `Simplib::Port`

The port upon which to listen for ``UDP`` connections

Default value: `514`

##### <a name="-rsyslog--read_journald"></a>`read_journald`

Data type: `Boolean`

Enable the processing of ``journald`` messages natively in Rsyslog

Default value: `true`

##### <a name="-rsyslog--logrotate"></a>`logrotate`

Data type: `Boolean`

Ensure that ``logrotate`` is enabled on this system

* You will need to configure specific logrotate settings via the
``logrotate`` module.

Default value: `simplib::lookup('simp_options::logrotate', {'default_value'                     => false})`

##### <a name="-rsyslog--pki"></a>`pki`

Data type: `Variant[Boolean,Enum['simp']]`

* If 'simp', include SIMP's pki module and use pki::copy to manage
  application certs in /etc/pki/simp_apps/rsyslog/x509
* If true, do *not* include SIMP's pki module, but still use pki::copy
  to manage certs in /etc/pki/simp_apps/rsyslog/x509
* If false, do not include SIMP's pki module and do not use pki::copy
  to manage certs.  You will need to appropriately assign a subset of:
  * app_pki_dir
  * app_pki_key
  * app_pki_cert
  * app_pki_ca
  * app_pki_ca_dir

Default value: `simplib::lookup('simp_options::pki', {'default_value'                           => false})`

##### <a name="-rsyslog--app_pki_external_source"></a>`app_pki_external_source`

Data type: `String`

* If pki = 'simp' or true, this is the directory from which certs will be
  copied, via pki::copy.  Defaults to /etc/pki/simp/x509.

* If pki = false, this variable has no effect.

Default value: `simplib::lookup('simp_options::pki::source', {'default_value'                   => '/etc/pki/simp/x509'})`

##### <a name="-rsyslog--app_pki_dir"></a>`app_pki_dir`

Data type: `Stdlib::Absolutepath`

Basepath of $default_net_stream_driver_ca_file, default_net_stream_driver_cert_file,
and $default_net_stream_driver_key_file

Default value: `'/etc/pki/simp_apps/rsyslog/x509'`

##### <a name="-rsyslog--rules"></a>`rules`

Data type: `Hash`

A hash of rsyslog rules, this parameter will enable you to create rules via hieradata

Default value: `{}`

### <a name="rsyslog--server"></a>`rsyslog::server`

This class is designed to configure the externally facing interfaces for a
RSyslog system. If you do not need external connectivity, you should just use
the stock ``rsyslog`` Class.

#### Parameters

The following parameters are available in the `rsyslog::server` class:

* [`enable_firewall`](#-rsyslog--server--enable_firewall)
* [`enable_selinux`](#-rsyslog--server--enable_selinux)
* [`enable_tcpwrappers`](#-rsyslog--server--enable_tcpwrappers)

##### <a name="-rsyslog--server--enable_firewall"></a>`enable_firewall`

Data type: `Boolean`

Enable the SIMP firewall rules for RSyslog

Default value: `simplib::lookup('simp_options::firewall', { 'default_value' => false })`

##### <a name="-rsyslog--server--enable_selinux"></a>`enable_selinux`

Data type: `Optional[Boolean]`

Enable the SIMP SELinux rules for RSyslog

Default value: `$facts['os']['selinux']['enforced']`

##### <a name="-rsyslog--server--enable_tcpwrappers"></a>`enable_tcpwrappers`

Data type: `Boolean`

Enable the SIMP TCPWrapper rules for RSyslog

Default value: `simplib::lookup('simp_options::tcpwrappers', { 'default_value' => false })`

## Defined types

### <a name="rsyslog--rule"></a>`rsyslog::rule`

This is used by the various ``rsyslog::rule::*`` Defined Types to apply rules
to the system.

The naming convention for the rule must be ``some_directory/rule_name.conf``

Feel free to use this Defined Type to add your own rules but remember that
**order matters**!

In general, the order will be:

  * 05 - Data Source Rules
  * 06 - Console Rules
  * 07 - Drop Rules
  * 10 - Remote Rules
  * 20 - Other/Miscellaneous Rules
  * 99 - Local Rules

* **See also**
  * https://access.redhat.com/documentation/en-us/red_hat_enterprise_linux/7/html/system_administrators_guide/ch-viewing_and_managing_log_files#s1-basic_configuration_of_rsyslog.html
    * Red Hat Basic Rsyslog Configuration
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/expressions.html
    * Expressions in Rsyslog
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/index.html
    * RainerScript Documentation

#### Examples

##### Collect All ``kern.err`` Messages

```puppet
rsyslog::rule { '99_simp_local/99_collect_kernel_errors.conf':
  content =>  "if prifilt('kern.err') then /var/log/kernel_errors.log"
}
```

##### Discard All ``info`` Messages

```puppet
rsyslog::rule::other { '98_discard_info.conf':
  rule =>  "if prifilt('*.info') then stop"
}
```

#### Parameters

The following parameters are available in the `rsyslog::rule` defined type:

* [`name`](#-rsyslog--rule--name)
* [`content`](#-rsyslog--rule--content)

##### <a name="-rsyslog--rule--name"></a>`name`

Data type: `Pattern['^[^/]\S+/\S+\.conf$']`

The filename that you will be dropping into place

* **WARNING:** This must **NOT** be an absolute path!

##### <a name="-rsyslog--rule--content"></a>`content`

Data type: `String`

The **exact content** of the rule to place in the target file

### <a name="rsyslog--rule--console"></a>`rsyslog::rule::console`

These rules first in priority. In general, the order will be:

  * Data Source Rules
  * Console Rules
  * Drop Rules
  * Remote Rules
  * Other/Miscellaneous Rules
  * Local Rules

* **See also**
  * https://access.redhat.com/documentation/en-us/red_hat_enterprise_linux/7/html/system_administrators_guide/ch-viewing_and_managing_log_files#s1-basic_configuration_of_rsyslog.html
    * Red Hat Basic Rsyslog Configuration
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/expressions.html
    * Expressions in Rsyslog
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/index.html
    * RainerScript Documentation

#### Examples

##### Log Emergency Messages to the Console

```puppet
rsyslog::rule::console { 'emergency_rule':
  rule  => 'prifilt(\'*.emerg\'),
  users => ['*']
}
```

#### Parameters

The following parameters are available in the `rsyslog::rule::console` defined type:

* [`name`](#-rsyslog--rule--console--name)
* [`rule`](#-rsyslog--rule--console--rule)
* [`users`](#-rsyslog--rule--console--users)

##### <a name="-rsyslog--rule--console--name"></a>`name`

Data type: `String`

The filename that you will be dropping into place

##### <a name="-rsyslog--rule--console--rule"></a>`rule`

Data type: `String`

The Rsyslog ``EXPRESSION`` to filter on

##### <a name="-rsyslog--rule--console--users"></a>`users`

Data type: `Array[String]`

Users to which to send the console messages

### <a name="rsyslog--rule--data_source"></a>`rsyslog::rule::data_source`

In general, the order will be:

  * Data Source Rules
  * Console Rules
  * Drop Rules
  * Remote Rules
  * Other/Miscellaneous Rules
  * Local Rules

* **See also**
  * https://access.redhat.com/documentation/en-us/red_hat_enterprise_linux/7/html/system_administrators_guide/ch-viewing_and_managing_log_files#s1-basic_configuration_of_rsyslog.html
    * Red Hat Basic Rsyslog Configuration
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/expressions.html
    * Expressions in Rsyslog
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/index.html
    * RainerScript Documentation

The filename that you will be dropping into place.

#### Examples

##### Collect Logs From ``/opt/log/my_app``

```puppet
rsyslog::rule::data_source { 'new_input':
  rule => @(EOM)
    input(type="imfile"
      File="/opt/log/my_app"
      StateFile="my_app"
      Tag="my_app"
      Facility="local6"
      Severity="notice"
    )
    |EOM
}
```

#### Parameters

The following parameters are available in the `rsyslog::rule::data_source` defined type:

* [`name`](#-rsyslog--rule--data_source--name)
* [`rule`](#-rsyslog--rule--data_source--rule)

##### <a name="-rsyslog--rule--data_source--name"></a>`name`

Data type: `String`

The filename that you will be dropping into place

##### <a name="-rsyslog--rule--data_source--rule"></a>`rule`

Data type: `String`

The Rsyslog ``EXPRESSION`` to filter on

### <a name="rsyslog--rule--drop"></a>`rsyslog::rule::drop`

In general, the order will be:

  * Data Source Rules
  * Console Rules
  * Drop Rules
  * Remote Rules
  * Other/Miscellanious Rules
  * Local Rules

* **See also**
  * https://access.redhat.com/documentation/en-us/red_hat_enterprise_linux/7/html/system_administrators_guide/ch-viewing_and_managing_log_files#s1-basic_configuration_of_rsyslog.html
    * Red Hat Basic Rsyslog Configuration
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/expressions.html
    * Expressions in Rsyslog
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/index.html
    * RainerScript Documentation

The filename that you will be dropping into place.

#### Examples

##### Drop Logs Matching ``^.*bad_stuff.*$``

```puppet
rsyslog::rule::drop { 'drop_bad_stuff':
  rule => 're_match($msg, '^.*bad_stuff.*$')'
}
```

#### Parameters

The following parameters are available in the `rsyslog::rule::drop` defined type:

* [`name`](#-rsyslog--rule--drop--name)
* [`rule`](#-rsyslog--rule--drop--rule)

##### <a name="-rsyslog--rule--drop--name"></a>`name`

Data type: `String`

The filename that you will be dropping into place

##### <a name="-rsyslog--rule--drop--rule"></a>`rule`

Data type: `String`

The Rsyslog ``EXPRESSION`` to filter on

### <a name="rsyslog--rule--local"></a>`rsyslog::rule::local`

**NOTE:** Any option that is not explicitly documented here matches the
``ruleset`` options in the Rsyslog documentation.

In general, the order will be:

  * Data Source Rules
  * Console Rules
  * Drop Rules
  * Remote Rules
  * Other/Miscellaneous Rules
  * Local Rules

NOTE: Since many of the parameters here may need to be modified on a
case-by-base basis, this defined type uses capabilities presented by the
``simplib::dlookup`` function to allow for either global overrides or
instance-specific overrides.

Global overrides work the same way as classes
(``rsyslog::rule::local::file_create_mode: '0644'``) but will affect **all**
instances of the defined type that are not specifically overridden as shown
below.

Instance specific overrides preclude the need for a resource collector in
that you can place the follwing in Hiera to affect a single instance named
``my_rule``: ``Rsyslog::Rule::Local[my_rule]::file_create_mode: '0600'``

* **See also**
  * https://access.redhat.com/documentation/en-us/red_hat_enterprise_linux/7/html/system_administrators_guide/ch-viewing_and_managing_log_files#s1-basic_configuration_of_rsyslog.html
    * Red Hat Basic Rsyslog Configuration
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/expressions.html
    * Expressions in Rsyslog
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/index.html
    * RainerScript Documentation

#### Examples

##### Capture OpenLDAP Logs Then Stop Processing

```puppet
rsyslog::rule::local { 'collect_openldap':
  rule            => "prifilt('local4.*')",
  target_log_file => '/var/log/slapd.log',
  stop_processing => true
}
```

#### Parameters

The following parameters are available in the `rsyslog::rule::local` defined type:

* [`name`](#-rsyslog--rule--local--name)
* [`rule`](#-rsyslog--rule--local--rule)
* [`target_log_file`](#-rsyslog--rule--local--target_log_file)
* [`stop_processing`](#-rsyslog--rule--local--stop_processing)
* [`dyna_file`](#-rsyslog--rule--local--dyna_file)
* [`template`](#-rsyslog--rule--local--template)
* [`dyna_file_cache_size`](#-rsyslog--rule--local--dyna_file_cache_size)
* [`zip_level`](#-rsyslog--rule--local--zip_level)
* [`very_robust_zip`](#-rsyslog--rule--local--very_robust_zip)
* [`flush_interval`](#-rsyslog--rule--local--flush_interval)
* [`async_writing`](#-rsyslog--rule--local--async_writing)
* [`flush_on_tx_end`](#-rsyslog--rule--local--flush_on_tx_end)
* [`io_buffer_size`](#-rsyslog--rule--local--io_buffer_size)
* [`dir_owner`](#-rsyslog--rule--local--dir_owner)
* [`dir_owner_num`](#-rsyslog--rule--local--dir_owner_num)
* [`dir_group`](#-rsyslog--rule--local--dir_group)
* [`dir_group_num`](#-rsyslog--rule--local--dir_group_num)
* [`file_owner`](#-rsyslog--rule--local--file_owner)
* [`file_owner_num`](#-rsyslog--rule--local--file_owner_num)
* [`file_group`](#-rsyslog--rule--local--file_group)
* [`file_group_num`](#-rsyslog--rule--local--file_group_num)
* [`file_create_mode`](#-rsyslog--rule--local--file_create_mode)
* [`dir_create_mode`](#-rsyslog--rule--local--dir_create_mode)
* [`fail_on_chown_failure`](#-rsyslog--rule--local--fail_on_chown_failure)
* [`create_dirs`](#-rsyslog--rule--local--create_dirs)
* [`sync`](#-rsyslog--rule--local--sync)
* [`sig_provider`](#-rsyslog--rule--local--sig_provider)
* [`cry_provider`](#-rsyslog--rule--local--cry_provider)
* [`queue_validation_log_level`](#-rsyslog--rule--local--queue_validation_log_level)
* [`queue_filename`](#-rsyslog--rule--local--queue_filename)
* [`queue_spool_directory`](#-rsyslog--rule--local--queue_spool_directory)
* [`queue_size`](#-rsyslog--rule--local--queue_size)
* [`queue_dequeue_batch_size`](#-rsyslog--rule--local--queue_dequeue_batch_size)
* [`queue_max_disk_space`](#-rsyslog--rule--local--queue_max_disk_space)
* [`queue_high_watermark`](#-rsyslog--rule--local--queue_high_watermark)
* [`queue_low_watermark`](#-rsyslog--rule--local--queue_low_watermark)
* [`queue_full_delay_mark`](#-rsyslog--rule--local--queue_full_delay_mark)
* [`queue_light_delay_mark`](#-rsyslog--rule--local--queue_light_delay_mark)
* [`queue_discard_mark`](#-rsyslog--rule--local--queue_discard_mark)
* [`queue_discard_severity`](#-rsyslog--rule--local--queue_discard_severity)
* [`queue_checkpoint_interval`](#-rsyslog--rule--local--queue_checkpoint_interval)
* [`queue_sync_queue_files`](#-rsyslog--rule--local--queue_sync_queue_files)
* [`queue_type`](#-rsyslog--rule--local--queue_type)
* [`queue_worker_threads`](#-rsyslog--rule--local--queue_worker_threads)
* [`queue_timeout_shutdown`](#-rsyslog--rule--local--queue_timeout_shutdown)
* [`queue_timeout_action_completion`](#-rsyslog--rule--local--queue_timeout_action_completion)
* [`queue_timeout_enqueue`](#-rsyslog--rule--local--queue_timeout_enqueue)
* [`queue_timeout_worker_thread_shutdown`](#-rsyslog--rule--local--queue_timeout_worker_thread_shutdown)
* [`queue_worker_thread_minimum_messages`](#-rsyslog--rule--local--queue_worker_thread_minimum_messages)
* [`queue_max_file_size`](#-rsyslog--rule--local--queue_max_file_size)
* [`queue_save_on_shutdown`](#-rsyslog--rule--local--queue_save_on_shutdown)
* [`queue_dequeue_slowdown`](#-rsyslog--rule--local--queue_dequeue_slowdown)
* [`queue_dequeue_time_begin`](#-rsyslog--rule--local--queue_dequeue_time_begin)
* [`queue_dequeue_time_end`](#-rsyslog--rule--local--queue_dequeue_time_end)
* [`content`](#-rsyslog--rule--local--content)

##### <a name="-rsyslog--rule--local--name"></a>`name`

Data type: `String`

The filename that you will be dropping into place

##### <a name="-rsyslog--rule--local--rule"></a>`rule`

Data type: `Optional[String[1]]`

The Rsyslog ``EXPRESSION`` to filter on

* **NOTE:** Do **NOT** include the leading ``if/then``
    * Correct:   ``rule => "prifilt('*.*')"
    * Incorrect: ``rule => "if prifilt('*.*') then"``

* This **must** be set if ``$content`` is undefined

Default value: `undef`

##### <a name="-rsyslog--rule--local--target_log_file"></a>`target_log_file`

Data type: `Optional[Stdlib::Absolutepath]`

The target log file that omfile will be writing to

* This **must** be set if ``$dyna_file`` is undefined

Default value: `undef`

##### <a name="-rsyslog--rule--local--stop_processing"></a>`stop_processing`

Data type: `Boolean`

Do not forward logs to any further ``ruleset``s after processing this ``ruleset``

Default value: `false`

##### <a name="-rsyslog--rule--local--dyna_file"></a>`dyna_file`

Data type: `Optional[String[1]]`

Set a ``dynamic`` filename using the property replacer rules

* **NOTE:** If you make this the filename path itself, a template will
  automatically be created for you. Otherwise, you must make sure to have a
  rsyslog template in place and pass the **name of the template** to this
  option

* Rsyslog templates can be created using the ``rsyslog::template::*``
  defined types

Default value: `undef`

##### <a name="-rsyslog--rule--local--template"></a>`template`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--dyna_file_cache_size"></a>`dyna_file_cache_size`

Data type: `Integer[0]`



Default value: `10`

##### <a name="-rsyslog--rule--local--zip_level"></a>`zip_level`

Data type: `Integer[0,9]`



Default value: `0`

##### <a name="-rsyslog--rule--local--very_robust_zip"></a>`very_robust_zip`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsyslog--rule--local--flush_interval"></a>`flush_interval`

Data type: `Integer[0]`



Default value: `0`

##### <a name="-rsyslog--rule--local--async_writing"></a>`async_writing`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsyslog--rule--local--flush_on_tx_end"></a>`flush_on_tx_end`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsyslog--rule--local--io_buffer_size"></a>`io_buffer_size`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--dir_owner"></a>`dir_owner`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--dir_owner_num"></a>`dir_owner_num`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--dir_group"></a>`dir_group`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--dir_group_num"></a>`dir_group_num`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--file_owner"></a>`file_owner`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--file_owner_num"></a>`file_owner_num`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--file_group"></a>`file_group`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--file_group_num"></a>`file_group_num`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--file_create_mode"></a>`file_create_mode`

Data type: `Stdlib::Filemode`



Default value: `simplib::dlookup('rsyslog::rule::local', 'file_create_mode', $name, { 'default_value' => '0640' })`

##### <a name="-rsyslog--rule--local--dir_create_mode"></a>`dir_create_mode`

Data type: `Stdlib::Filemode`



Default value: `simplib::dlookup('rsyslog::rule::local', 'dir_create_mode', $name, { 'default_value' => '0750' })`

##### <a name="-rsyslog--rule--local--fail_on_chown_failure"></a>`fail_on_chown_failure`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsyslog--rule--local--create_dirs"></a>`create_dirs`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsyslog--rule--local--sync"></a>`sync`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsyslog--rule--local--sig_provider"></a>`sig_provider`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--cry_provider"></a>`cry_provider`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_validation_log_level"></a>`queue_validation_log_level`

Data type: `Simplib::PuppetLogLevel`



Default value: `simplib::dlookup('rsyslog::rule::local', 'queue_validation_log_level', $name, { 'default_value' => 'warning' })`

##### <a name="-rsyslog--rule--local--queue_filename"></a>`queue_filename`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_spool_directory"></a>`queue_spool_directory`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_size"></a>`queue_size`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_dequeue_batch_size"></a>`queue_dequeue_batch_size`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_max_disk_space"></a>`queue_max_disk_space`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_high_watermark"></a>`queue_high_watermark`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_low_watermark"></a>`queue_low_watermark`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_full_delay_mark"></a>`queue_full_delay_mark`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_light_delay_mark"></a>`queue_light_delay_mark`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_discard_mark"></a>`queue_discard_mark`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_discard_severity"></a>`queue_discard_severity`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_checkpoint_interval"></a>`queue_checkpoint_interval`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_sync_queue_files"></a>`queue_sync_queue_files`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsyslog--rule--local--queue_type"></a>`queue_type`

Data type: `Rsyslog::QueueType`



Default value: `'Direct'`

##### <a name="-rsyslog--rule--local--queue_worker_threads"></a>`queue_worker_threads`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_timeout_shutdown"></a>`queue_timeout_shutdown`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_timeout_action_completion"></a>`queue_timeout_action_completion`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_timeout_enqueue"></a>`queue_timeout_enqueue`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_timeout_worker_thread_shutdown"></a>`queue_timeout_worker_thread_shutdown`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_worker_thread_minimum_messages"></a>`queue_worker_thread_minimum_messages`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_max_file_size"></a>`queue_max_file_size`

Data type: `Optional[String[1]]`



Default value: `simplib::dlookup('rsyslog::rule::local', 'queue_max_file_size', $name, { 'default_value' => undef })`

##### <a name="-rsyslog--rule--local--queue_save_on_shutdown"></a>`queue_save_on_shutdown`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsyslog--rule--local--queue_dequeue_slowdown"></a>`queue_dequeue_slowdown`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_dequeue_time_begin"></a>`queue_dequeue_time_begin`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--queue_dequeue_time_end"></a>`queue_dequeue_time_end`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--local--content"></a>`content`

Data type: `Optional[String[1]]`

the **entire* content of the rsyslog::rule

* If you do not specify this, ``$rule`` is a required variable

* If you do specify this, ``$rule`` will be ignored

Default value: `undef`

### <a name="rsyslog--rule--other"></a>`rsyslog::rule::other`

The main reason to use this is to ensure proper ordering in the stack. If you
want to insert a rule anywhere, use the ``$rsyslog::rule`` Defined Type

In general, the order will be:

  * Data Source Rules
  * Console Rules
  * Drop Rules
  * Remote Rules
  * Other/Miscellaneous Rules
  * Local Rules

fine: rsyslog::rule::other

* **See also**
  * https://access.redhat.com/documentation/en-us/red_hat_enterprise_linux/7/html/system_administrators_guide/ch-viewing_and_managing_log_files#s1-basic_configuration_of_rsyslog.html
    * Red Hat Basic Rsyslog Configuration
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/expressions.html
    * Expressions in Rsyslog
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/index.html
    * RainerScript Documentation

The filename that you will be dropping into place.

#### Examples

##### Send All ``local0`` Messages to ``1.2.3.4`` via TCP

```puppet
rsyslog::rule::other { 'send_local0_away':
  rule =>  "if prifilt('local0.*') then @@1.2.3.4"
}
```

#### Parameters

The following parameters are available in the `rsyslog::rule::other` defined type:

* [`name`](#-rsyslog--rule--other--name)
* [`rule`](#-rsyslog--rule--other--rule)

##### <a name="-rsyslog--rule--other--name"></a>`name`

Data type: `String`

The filename that you will be dropping into place

##### <a name="-rsyslog--rule--other--rule"></a>`rule`

Data type: `String`

The Rsyslog ``EXPRESSION`` to filter on

### <a name="rsyslog--rule--remote"></a>`rsyslog::rule::remote`

The rule will include a forwarding ('omfwd') action for each
primary and failover syslog server specified via ``$dest`` and
``$failover_log_servers``, respectively.

In general, the order will be:

  * Data Source Rules
  * Console Rules
  * Drop Rules
  * Remote Rules
  * Other/Miscellaneous Rules
  * Local Rules

In general, individual send stream driver settings are properly supported
with the Rsyslog 8 EL versions available for CentOS 7 and the Rsyslog 7
EL versions available for CentOS 6. However, for TLS support, you must
also configure global Rsyslog parameters as follows:

* TLS sending and/or receiving requires the global DefaultNetStreamDriver,
  DefaultNetStreamDriverCAFile, DefaultNetStreamDriverCertFile, and
  DefaultNetStreamDriverKeyFile parameters to be configure via
  ``rsyslog::config``.

* TLS sending for Rsyslog 7 EL versions requires the global
  ActionSendStreamDriverMode configuration parameter to be configured via
  ``rsyslog::config`` **IN ADDITION TO** the ``$stream_driver_mode``.

------------------------------------------------------------------------

> **WARNING**
>
> If possible, this module will take pains to prevent adding a target that is
> equivalent to the current system to prevent syslog loops.
>
> Unfortunately, there is **no** foolproof method for getting this correct
> 100% of the time so please take care when setting your destination targets.
>
> **WARNING**

------------------------------------------------------------------------

 * This **must** be set if ``$content`` is left empty

* **See also**
  * https://access.redhat.com/documentation/en-us/red_hat_enterprise_linux/7/html/system_administrators_guide/ch-viewing_and_managing_log_files#s1-basic_configuration_of_rsyslog.html
    * Red Hat Basic Rsyslog Configuration
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/expressions.html
    * Expressions in Rsyslog
  * https://www.rsyslog.com/doc/v8-stable/rainerscript/index.html
    * RainerScript Documentation
  * https://simp.readthedocs.io/en/stable/user_guide/HOWTO/Central_Log_Collection.html

#### Examples

##### Send All ``local0`` Messages to ``1.2.3.4`` via TCP

```puppet
rsyslog::rule::remote { 'send_local0_away':
  rule => "prifilt('local0.*')",
  dest => ['1.2.3.4']
}
```

#### Parameters

The following parameters are available in the `rsyslog::rule::remote` defined type:

* [`name`](#-rsyslog--rule--remote--name)
* [`rule`](#-rsyslog--rule--remote--rule)
* [`stop_processing`](#-rsyslog--rule--remote--stop_processing)
* [`template`](#-rsyslog--rule--remote--template)
* [`dest`](#-rsyslog--rule--remote--dest)
* [`dest_type`](#-rsyslog--rule--remote--dest_type)
* [`failover_log_servers`](#-rsyslog--rule--remote--failover_log_servers)
* [`tcp_framing`](#-rsyslog--rule--remote--tcp_framing)
* [`zip_level`](#-rsyslog--rule--remote--zip_level)
* [`max_error_messages`](#-rsyslog--rule--remote--max_error_messages)
* [`compression_mode`](#-rsyslog--rule--remote--compression_mode)
* [`compression_stream_flush_on_tx_end`](#-rsyslog--rule--remote--compression_stream_flush_on_tx_end)
* [`rebind_interval`](#-rsyslog--rule--remote--rebind_interval)
* [`keep_alive`](#-rsyslog--rule--remote--keep_alive)
* [`keep_alive_probes`](#-rsyslog--rule--remote--keep_alive_probes)
* [`keep_alive_interval`](#-rsyslog--rule--remote--keep_alive_interval)
* [`keep_alive_time`](#-rsyslog--rule--remote--keep_alive_time)
* [`action_resume_interval`](#-rsyslog--rule--remote--action_resume_interval)
* [`action_resume_retry_count`](#-rsyslog--rule--remote--action_resume_retry_count)
* [`stream_driver`](#-rsyslog--rule--remote--stream_driver)
* [`stream_driver_mode`](#-rsyslog--rule--remote--stream_driver_mode)
* [`stream_driver_auth_mode`](#-rsyslog--rule--remote--stream_driver_auth_mode)
* [`stream_driver_permitted_peers`](#-rsyslog--rule--remote--stream_driver_permitted_peers)
* [`resend_last_msg_on_reconnect`](#-rsyslog--rule--remote--resend_last_msg_on_reconnect)
* [`udp_send_to_all`](#-rsyslog--rule--remote--udp_send_to_all)
* [`queue_validation_log_level`](#-rsyslog--rule--remote--queue_validation_log_level)
* [`queue_filename`](#-rsyslog--rule--remote--queue_filename)
* [`queue_spool_directory`](#-rsyslog--rule--remote--queue_spool_directory)
* [`queue_size`](#-rsyslog--rule--remote--queue_size)
* [`queue_dequeue_batch_size`](#-rsyslog--rule--remote--queue_dequeue_batch_size)
* [`queue_max_disk_space`](#-rsyslog--rule--remote--queue_max_disk_space)
* [`queue_high_watermark`](#-rsyslog--rule--remote--queue_high_watermark)
* [`queue_low_watermark`](#-rsyslog--rule--remote--queue_low_watermark)
* [`queue_full_delay_mark`](#-rsyslog--rule--remote--queue_full_delay_mark)
* [`queue_light_delay_mark`](#-rsyslog--rule--remote--queue_light_delay_mark)
* [`queue_discard_mark`](#-rsyslog--rule--remote--queue_discard_mark)
* [`queue_discard_severity`](#-rsyslog--rule--remote--queue_discard_severity)
* [`queue_checkpoint_interval`](#-rsyslog--rule--remote--queue_checkpoint_interval)
* [`queue_sync_queue_files`](#-rsyslog--rule--remote--queue_sync_queue_files)
* [`queue_type`](#-rsyslog--rule--remote--queue_type)
* [`queue_worker_threads`](#-rsyslog--rule--remote--queue_worker_threads)
* [`queue_timeout_shutdown`](#-rsyslog--rule--remote--queue_timeout_shutdown)
* [`queue_timeout_action_completion`](#-rsyslog--rule--remote--queue_timeout_action_completion)
* [`queue_timeout_enqueue`](#-rsyslog--rule--remote--queue_timeout_enqueue)
* [`queue_timeout_worker_thread_shutdown`](#-rsyslog--rule--remote--queue_timeout_worker_thread_shutdown)
* [`queue_worker_thread_minimum_messages`](#-rsyslog--rule--remote--queue_worker_thread_minimum_messages)
* [`queue_max_file_size`](#-rsyslog--rule--remote--queue_max_file_size)
* [`queue_save_on_shutdown`](#-rsyslog--rule--remote--queue_save_on_shutdown)
* [`queue_dequeue_slowdown`](#-rsyslog--rule--remote--queue_dequeue_slowdown)
* [`queue_dequeue_time_begin`](#-rsyslog--rule--remote--queue_dequeue_time_begin)
* [`queue_dequeue_time_end`](#-rsyslog--rule--remote--queue_dequeue_time_end)
* [`content`](#-rsyslog--rule--remote--content)

##### <a name="-rsyslog--rule--remote--name"></a>`name`

Data type: `String`

The filename that you will be dropping into place

##### <a name="-rsyslog--rule--remote--rule"></a>`rule`

Data type: `Optional[String[1]]`

The Rsyslog ``EXPRESSION`` to filter on

* This should only be the matching part of the expression, the remaining
  parameters take care of ensuring that the material is properly routed.

* **NOTE:** Do **NOT** include the leading ``if/then``
    * Correct:   ``rule => "prifilt('*.*')"
    * Incorrect: ``rule => "if prifilt('*.*') then"``

Default value: `undef`

##### <a name="-rsyslog--rule--remote--stop_processing"></a>`stop_processing`

Data type: `Boolean`

Do not forward logs to any further ``ruleset``s after processing this ``ruleset``

Default value: `false`

##### <a name="-rsyslog--rule--remote--template"></a>`template`

Data type: `Optional[String[1]]`

The template that should be used to format the content

Default value: `undef`

##### <a name="-rsyslog--rule--remote--dest"></a>`dest`

Data type: `Simplib::Netlist`

If filled, logs matching ``$rule`` will be sent to **all hosts** in this Array.

* **WARNING:** If using this, do **NOT** add a destination to your ``rule``

Default value: `[]`

##### <a name="-rsyslog--rule--remote--dest_type"></a>`dest_type`

Data type: `Enum['tcp','udp','relp']`

The destination type for all entries in ``$dest``

* At this time, if you wish to have different types per destination, you
  will need to either create a ``rsyslog::rule::remote`` for each destnation
  or craft your own ruleset and leave ``$dest`` empty.

Default value: `'tcp'`

##### <a name="-rsyslog--rule--remote--failover_log_servers"></a>`failover_log_servers`

Data type: `Simplib::Netlist`

The listed systems will be used as failover servers for all logs matching
this ``rule``

* Uses ``$dest_type`` above

Default value: `[]`

##### <a name="-rsyslog--rule--remote--tcp_framing"></a>`tcp_framing`

Data type: `Enum['traditional','octet-counted']`



Default value: `'traditional'`

##### <a name="-rsyslog--rule--remote--zip_level"></a>`zip_level`

Data type: `Integer[0,9]`



Default value: `0`

##### <a name="-rsyslog--rule--remote--max_error_messages"></a>`max_error_messages`

Data type: `Integer[0]`



Default value: `5`

##### <a name="-rsyslog--rule--remote--compression_mode"></a>`compression_mode`

Data type: `Enum['none','single','stream:always']`



Default value: `'none'`

##### <a name="-rsyslog--rule--remote--compression_stream_flush_on_tx_end"></a>`compression_stream_flush_on_tx_end`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsyslog--rule--remote--rebind_interval"></a>`rebind_interval`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--keep_alive"></a>`keep_alive`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--keep_alive_probes"></a>`keep_alive_probes`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--keep_alive_interval"></a>`keep_alive_interval`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--keep_alive_time"></a>`keep_alive_time`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--action_resume_interval"></a>`action_resume_interval`

Data type: `Integer[0]`



Default value: `30`

##### <a name="-rsyslog--rule--remote--action_resume_retry_count"></a>`action_resume_retry_count`

Data type: `Integer[-1]`



Default value: `-1`

##### <a name="-rsyslog--rule--remote--stream_driver"></a>`stream_driver`

Data type: `Optional[String[1]]`

* This is only used to set the StreamDriver directive in the forwarding
  actions for remote servers if TLS is enabled and ``$dest_type`` is
  not UDP.

* Overridden by 'DefaultNetstreamDriver' global stream configuration
  specified by ``rsyslog::config::default_net_stream_driver``.

Default value: `undef`

##### <a name="-rsyslog--rule--remote--stream_driver_mode"></a>`stream_driver_mode`

Data type: `Integer[0]`

* This is only used to set the StreamDriverMode directive in the
  forwarding actions for remote servers if TLS is enabled and
  ``$dest_type`` is not UDP.

Default value: `1`

##### <a name="-rsyslog--rule--remote--stream_driver_auth_mode"></a>`stream_driver_auth_mode`

Data type: `String`

This is only used to set the StreamDriverAuthMode directive in the
forwarding actions for remote servers if TLS is enabled and
``$dest_type`` is not UDP.

Default value: `'x509/name'`

##### <a name="-rsyslog--rule--remote--stream_driver_permitted_peers"></a>`stream_driver_permitted_peers`

Data type: `Optional[String[1]]`

* This is only used to set the StreamDriverPermittedPeers directive
  in the forwarding actions for remote servers if TLS is enabled and
  ``$dest_type`` is not UDP.

* If this is set, the value will be used for all forwarding actions
  for the remote servers in ``$dest`` and ``$failover_log_servers``.

* If this is undefined,

  - If *ALL* of the remote servers in ``$dest`` and
    ``$failover_log_servers`` are specified as a hostname variants, the
    StreamDriverPermittedPeers directive for the forwarding action for
    each server will be set to that server's hostname.

  - If *ANY* and of the remote servers in ``$dest`` and
    ``$failover_log_servers`` is specified as an IP address variant, the
    StreamDriverPermittedPeers directive for the forwarding action for
    each server will be set to the domain of the Puppet client.
    This behavior provides backward compatibility with earlier
    versions of this module.

* rsyslog expects StreamDriverPermittedPeers to be a comma-separated
  list of fingerprints (SHA1) and/or names of remote peers, which it
  will use to match against the certificate presented from the remote
  server.

Default value: `undef`

##### <a name="-rsyslog--rule--remote--resend_last_msg_on_reconnect"></a>`resend_last_msg_on_reconnect`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsyslog--rule--remote--udp_send_to_all"></a>`udp_send_to_all`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsyslog--rule--remote--queue_validation_log_level"></a>`queue_validation_log_level`

Data type: `Simplib::PuppetLogLevel`



Default value: `simplib::dlookup('rsyslog::rule::remote', 'queue_validation_log_level', $name, { 'default_value' => 'warning' })`

##### <a name="-rsyslog--rule--remote--queue_filename"></a>`queue_filename`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_spool_directory"></a>`queue_spool_directory`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_size"></a>`queue_size`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_dequeue_batch_size"></a>`queue_dequeue_batch_size`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_max_disk_space"></a>`queue_max_disk_space`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_high_watermark"></a>`queue_high_watermark`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_low_watermark"></a>`queue_low_watermark`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_full_delay_mark"></a>`queue_full_delay_mark`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_light_delay_mark"></a>`queue_light_delay_mark`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_discard_mark"></a>`queue_discard_mark`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_discard_severity"></a>`queue_discard_severity`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_checkpoint_interval"></a>`queue_checkpoint_interval`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_sync_queue_files"></a>`queue_sync_queue_files`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsyslog--rule--remote--queue_type"></a>`queue_type`

Data type: `Rsyslog::QueueType`



Default value: `'LinkedList'`

##### <a name="-rsyslog--rule--remote--queue_worker_threads"></a>`queue_worker_threads`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_timeout_shutdown"></a>`queue_timeout_shutdown`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_timeout_action_completion"></a>`queue_timeout_action_completion`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_timeout_enqueue"></a>`queue_timeout_enqueue`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_timeout_worker_thread_shutdown"></a>`queue_timeout_worker_thread_shutdown`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_worker_thread_minimum_messages"></a>`queue_worker_thread_minimum_messages`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_max_file_size"></a>`queue_max_file_size`

Data type: `Optional[String[1]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_save_on_shutdown"></a>`queue_save_on_shutdown`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsyslog--rule--remote--queue_dequeue_slowdown"></a>`queue_dequeue_slowdown`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_dequeue_time_begin"></a>`queue_dequeue_time_begin`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--queue_dequeue_time_end"></a>`queue_dequeue_time_end`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsyslog--rule--remote--content"></a>`content`

Data type: `Optional[String[1]]`

the **entire* content of the rsyslog::rule

* If you do not specify this, ``$rule`` is a required variable

* If you do specify this, ``$rule`` will be ignored

Default value: `undef`

### <a name="rsyslog--template--list"></a>`rsyslog::template::list`

RSyslog list templates can contain properties and constants. In order to
capture this functionality, we have opted for making a hash of these. The
Hash will be ordered as given to the content variable.

#### Examples

##### Content Settings

```puppet
$content_hash = {
  'constant' => 'values="Syslog MSG is: \'"',
  'property' => 'name="msg"'
}

rsyslog::template::list { 'example_list':
  $content => $content_hash
}

### Produces:

template(name="example_list" type="list") {
  constant(value="Syslog MSG is: '")
  property(name="msg")
}
```

#### Parameters

The following parameters are available in the `rsyslog::template::list` defined type:

* [`name`](#-rsyslog--template--list--name)
* [`content`](#-rsyslog--template--list--content)

##### <a name="-rsyslog--template--list--name"></a>`name`

Data type: `String`

The literal name (not path) of the ``file`` that will be written

##### <a name="-rsyslog--template--list--content"></a>`content`

Data type: `Hash[String,String,1]`

The rsyslog list content that you wish to add to the system, as a Hash

### <a name="rsyslog--template--plugin"></a>`rsyslog::template::plugin`

**NOTE:** Plugins are **as-is**. This means that you will only supply the
plugin name and assume that the plugin has already been loaded by RSyslog.

#### Examples

##### Adding the ``my_plugin`` Plugin to the System

```puppet
rsyslog::template::string { 'example_plugin':
  $plugin => 'my_plugin'
}

### Produces:

template(name="example_plugin" type="plugin" plugin="my_plugin")
```

#### Parameters

The following parameters are available in the `rsyslog::template::plugin` defined type:

* [`name`](#-rsyslog--template--plugin--name)
* [`plugin`](#-rsyslog--template--plugin--plugin)

##### <a name="-rsyslog--template--plugin--name"></a>`name`

Data type: `String`

The literal name of the ``file`` (not the full path) that will be used

##### <a name="-rsyslog--template--plugin--plugin"></a>`plugin`

Data type: `String`

The rsyslog plugin content that you wish to add to the system

* This is provided, without formatting, directly into the target file

### <a name="rsyslog--template--string"></a>`rsyslog::template::string`

You'll need to write the entire template line due to the complexity of the
rsyslog configuration parameters.

Leading spaces will be removed.

#### Examples

##### Template String

```puppet
rsyslog::template::string { 'example':
  $content => '/var/log/hosts/%HOSTNAME%/example.log'
}

### Produces:

template(name="example" type="string" string="/var/log/hosts/%HOSTNAME%/example.log")
```

#### Parameters

The following parameters are available in the `rsyslog::template::string` defined type:

* [`name`](#-rsyslog--template--string--name)
* [`string`](#-rsyslog--template--string--string)

##### <a name="-rsyslog--template--string--name"></a>`name`

Data type: `String`

The literal name of the ``file`` (not file path) that will be used

##### <a name="-rsyslog--template--string--string"></a>`string`

Data type: `String`

The rsyslog template string that you wish to add to the system

* This is fed, without formatting, directly into the target file

### <a name="rsyslog--template--subtree"></a>`rsyslog::template::subtree`

You'll need to write the entire subtree line due to the complexity of the
rsyslog configuration parameters.

#### Examples

##### Subtree (From the Official RSyslog Docs)

```puppet
rsyslog::template::subtree { 'example_subtree':
  $variables => ['$!usr!tp12!msg = $msg;', '$!usr!tp12!dataflow = field($msg, 58, 2);'],
  $subtree   => '$!usr!tp12'
}

### Produces:

set $!usr!tp12!msg = $msg;
set $!usr!tp12!dataflow = field($msg, 58, 2);
template(name="example" type="subtree" subtree="$!usr!tp12")
```

#### Parameters

The following parameters are available in the `rsyslog::template::subtree` defined type:

* [`name`](#-rsyslog--template--subtree--name)
* [`subtree`](#-rsyslog--template--subtree--subtree)
* [`variables`](#-rsyslog--template--subtree--variables)

##### <a name="-rsyslog--template--subtree--name"></a>`name`

Data type: `String`

The literal name of the ``file`` (not a path) that will be used

##### <a name="-rsyslog--template--subtree--subtree"></a>`subtree`

Data type: `String`

The rsyslog subtree content that you wish to add to the system

* This is fed, without formatting, directly into the subtree parameter

##### <a name="-rsyslog--template--subtree--variables"></a>`variables`

Data type: `Array[String]`

Variables to be set **prior** to the template being created

Default value: `[]`

## Data types

### <a name="Rsyslog--Boolean"></a>`Rsyslog::Boolean`

Representation of boolean values that are translated to 'on' and 'off'
in Rsyslog configuration

Alias of `Variant[Enum['on','off'], Boolean]`

### <a name="Rsyslog--Options"></a>`Rsyslog::Options`

Hash of options to be used for Rsyslog global, legacy global or module configuration

Alias of `Hash[String, Variant[Numeric,String]]`

### <a name="Rsyslog--QueueType"></a>`Rsyslog::QueueType`

Rsyslog Queue Types

Alias of `Enum['FixedArray', 'LinkedList', 'Direct', 'Disk']`

